@@ -14,11 +14,11 @@ function(n) {
   crTot <- 0L
   n <- .C('getNumSlaves', n = as.integer(n), DUP = FALSE, PACKAGE = "spMC")$n
   if (n <= 1L) {
-    cat("Parallel computation is not allowed. CPU cores in use: 1.\n")
+    cat("Parallel computation will not perform. CPU cores in use: 1.\n")
   }
   else {
     crTot <- .C('getNumCores', n = as.integer(crTot), DUP = FALSE, PACKAGE = "spMC")$n
-    cat("Parallel computation is allowed.\n")
+    cat("Parallel computation will perform.\n")
     cat("  Total CPU cores available: ", crTot, ".\n", sep = "")
     cat("  CPU cores in use: ", n, ".\n", sep = "")
   }
